@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence, Union
+from typing import Dict, List, Sequence, Union
 
 from .literals import AuthenticationTypeType, AZStatusType, ServiceUpdateStatusType, SourceTypeType
 
@@ -1033,7 +1033,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
